==> fvtt-les-heritiers-10.0.33.zip: fvtt-les-heritiers/modules/heritiers-config.js <==

export const HERITIERS_CONFIG = {

  caracList: {
    "agi": "Agilité",
    "con": "Constitution",
    "for": "Force",
    "prec": "Précision",
    "esp": "Esprit",
    "per": "Perception",
    "pres": "Prestance",
    "san": "Sang-Froid"
  },

  competenceCategorie  : {
    "utile": "Utile",
    "futile": "Futile"
  },
  
  contactType: {
    contact: "Contact", 
    allie: "Allié",
    ennemi: "Ennemi",
    interet: "Personne d'interêt"
  },

  competenceProfil  : {
    "aventurier": {kind: "physical", name: "Aventurier"},
    "roublard": {kind: "physical",name: "Roublard"},
    "combattant": {kind: "physical",name:"Combattant"},
    "erudit": {kind: "mental",name:"Erudit"},
    "savant": {kind: "mental",name:"Savant"},
    "gentleman": {kind: "mental",name:"Gentleman"}
  },
  baseTestPouvoir: {
    "feerie": "Féerie",
    "masque": "Masque",
    "autre": "Autre"
  },
  resistancePouvoir: {
    "aucune": "Aucune",
    "physiquepassive": "Physique Passive",
    "physiqueactive": "Physique Active",
    "psychiquepassive": "Psychique Passive",
    "psychiqueactive": "Psychique Active",
    "autre": "Autre",
  },
  typePouvoir: {
    "actif": "Actif",
    "passif": "Passif",
    "metamorphose": "Métamorphose"
  },
  statutMasque: {
    "masque": "Masqué",
    "demasque":"Démasqué"
  },
  niveauPouvoir: {
    "normal": "Normal",
    "profond": "Profond",
    "legendaire": "Légendaire"
  },
  masquePouvoir: {
    "masque": "Masqué",
    "demasque": "Démasqué"
  },
  seuilsDifficulte: {
    "0": "Aucun/Non applicable",
    "5": "Enfantine",
    "6": "Triviale",
    "7": "Moins Triviale",
    "8": "Aisée",
    "7": "Moins Aisée",
    "10": "Normale",
    "11": "Moins Normale",
    "12": "Compliquée",
    "13": "Plus Compliquée",
    "14": "Difficile",
    "15": "Plus Difficile",
    "16": "Très Difficile",
    "17": "Très Très Difficile",
    "18": "Critique",
    "19": "Plus Critique",
    "20": "Insurmontable",
    "20": "Très Insurmontable",
    "22": "Surhumaine",
    "23": "Très Surhumaine",
    "24": "Epique",
    "25": "Plus Epique",
    "26": "Légendaire",
    "26": "Très Légendaire",
    "28": "Mythique",
    "29": "Plus Mythique",
    "30": "Divine"
  },

  categorieArme : {
    "trait": "Arme de trait",
    "poing": "Arme de poing",
    "epaule": "Arme d'épaule",
    "lourde": "Arme lourde",
    "blanche": "Arme blanche",
    "improvise": "Arme improvisée",
    "explosif": "Explosif"
  }, 
  typeArme: {
    "naturelle": "Arme naturelle",
    "trait": "Trait",
    "pistolet": "Pistolet",
    "simpleaction": "Simple Action",
    "doubleaction": "Double Action",
    "doublecanon": "Double Canon",
    "semiauto": "Semi Automatique",
    "auto": "Automatique",
    "manuel": "Manuel",
    "verrou": "Verrou",
    "special": "Spéciale",
    "legere": "Légère",
    "lourde": "Lourde",
    "explosif": "Explosif"
  },
  armeLegalite: {
    "libre": "Libre (L)",
    "controlee": "Contrôlée (C)",
    "prohibee": "Prohibée (P)"
  },
  armeDissimulation :{
    "tresfacile": "Très facile (TF)",
    "facile": "Facile (F)",
    "difficile": "Difficile (D)",
    "impossible": "Impossible (I)"
  },
  typeProtection : {
    "balle": "Protège ds balles",
    "melee": "Protège en mélée",
    "tout": "Tout type de dégats"
  },
  typeFee: {
    "traditionnelle": "Traditionnelle",
    "moderne": "Moderne",
    "orientale": "Orientale"
  }

  
}

==> fvtt-les-heritiers-12.0.0.zip: fvtt-les-heritiers/modules/heritiers-config.js <==

export const HERITIERS_CONFIG = {

  caracList: {
    "agi": "Agilité",
    "con": "Constitution",
    "for": "Force",
    "prec": "Précision",
    "esp": "Esprit",
    "per": "Perception",
    "pres": "Prestance",
    "san": "Sang-Froid"
  },

  competenceCategorie  : {
    "utile": "Utile",
    "futile": "Futile"
  },
  
  contactType: {
    contact: "Contact", 
    allie: "Allié",
    ennemi: "Ennemi",
    interet: "Personne d'interêt"
  },

  competenceProfil  : {
    "aventurier": {kind: "physical", name: "Aventurier"},
    "roublard": {kind: "physical",name: "Roublard"},
    "combattant": {kind: "physical",name:"Combattant"},
    "erudit": {kind: "mental",name:"Erudit"},
    "savant": {kind: "mental",name:"Savant"},
    "gentleman": {kind: "mental",name:"Gentleman"}
  },
  baseTestPouvoir: {
    "feerie": "Féerie",
    "masque": "Masque",
    "autre": "Autre"
  },
  resistancePouvoir: {
    "aucune": "Aucune",
    "physiquepassive": "Physique Passive",
    "physiqueactive": "Physique Active",
    "psychiquepassive": "Psychique Passive",
    "psychiqueactive": "Psychique Active",
    "autre": "Autre",
  },
  typePouvoir: {
    "actif": "Actif",
    "passif": "Passif",
    "metamorphose": "Métamorphose"
  },
  statutMasque: {
    "masque": "Masqué",
    "demasque":"Démasqué"
  },
  niveauPouvoir: {
    "normal": "Normal",
    "profond": "Profond",
    "legendaire": "Légendaire"
  },
  masquePouvoir: {
    "masque": "Masqué",
    "demasque": "Démasqué"
  },
  seuilsDifficulte: {
    "-1": "Aucun/Non applicable",
    "5": "Enfantine",
    "6": "Triviale",
    "7": "Moins Triviale",
    "8": "Aisée",
    "7": "Moins Aisée",
    "10": "Normale",
    "11": "Moins Normale",
    "12": "Compliquée",
    "13": "Plus Compliquée",
    "14": "Difficile",
    "15": "Plus Difficile",
    "16": "Très Difficile",
    "17": "Très Très Difficile",
    "18": "Critique",
    "19": "Plus Critique",
    "20": "Insurmontable",
    "20": "Très Insurmontable",
    "22": "Surhumaine",
    "23": "Très Surhumaine",
    "24": "Epique",
    "25": "Plus Epique",
    "26": "Légendaire",
    "26": "Très Légendaire",
    "28": "Mythique",
    "29": "Plus Mythique",
    "30": "Divine"
  },

  attaqueCible: {
    "none": "Aucune",
    "membre": "Membre",
    "main": "Main",
    "tete": "Tête/Coeur"
  },
  
  categorieArme : {
    "trait": "Arme de trait",
    "poing": "Arme de poing",
    "epaule": "Arme d'épaule",
    "lourde": "Arme lourde",
    "blanche": "Arme blanche",
    "improvise": "Arme improvisée",
    "explosif": "Explosif"
  }, 
  typeArme: {
    "naturelle": "Arme naturelle",
    "trait": "Trait",
    "pistolet": "Pistolet",
    "simpleaction": "Simple Action",
    "doubleaction": "Double Action",
    "doublecanon": "Double Canon",
    "semiauto": "Semi Automatique",
    "auto": "Automatique",
    "manuel": "Manuel",
    "verrou": "Verrou",
    "special": "Spéciale",
    "legere": "Légère",
    "lourde": "Lourde",
    "explosif": "Explosif"
  },
  armeLegalite: {
    "libre": "Libre (L)",
    "controlee": "Contrôlée (C)",
    "prohibee": "Prohibée (P)"
  },
  armeDissimulation :{
    "tresfacile": "Très facile (TF)",
    "facile": "Facile (F)",
    "difficile": "Difficile (D)",
    "impossible": "Impossible (I)"
  },
  typeProtection : {
    "balle": "Protège ds balles",
    "melee": "Protège en mélée",
    "tout": "Tout type de dégats"
  },
  typeFee: {
    "traditionnelle": "Traditionnelle",
    "moderne": "Moderne",
    "orientale": "Orientale"
  }, 
  typeContact: {
    "contact": "Contact",
    "allie": "Allié",
    "ennemi": "Ennemi",
    "interet": "Personne d'interêt"
  },
  niveauContact: {
    "1": "1",
    "2": "2",
    "3": "3",
  },
  pointsUsageList: {
    "1": "1",
    "2": "2",
    "3": "3",
    "4": "4",
  },
  attaquePlusieursList : {
    "0": "0",
    "1": "+1",
    "2": "+2",
  },
  attaque2ArmesListe: [
    {value: "0", label:  "Aucun"}, 
    {value: "-4", label: "Deux armes à 1 main"},
    {value: "-2", label: "Deux armes naturelles"},
    {value: "-2", label: "Avec spécialisation \"Mauvaise Main\""}
  ],
  typeProfil: {
    "mineur": "Mineur",
    "majeur": "Majeur",
  },
  bonusMalusContext: [ 
    {value: "-6", label: "-6"},
    {value: "-5", label: "-5"},
    {value: "-4", label: "-4"},
    {value: "-3", label: "-3"},
    {value: "-2", label: "-2"},
    {value: "-1", label: "-1"},
    {value: "0", label: "0"},
    {value: "1", label: "+1"},
    {value: "2", label: "+2"},
    {value: "3", label: "+3"},
    {value: "4", label: "+4"},
    {value: "5", label: "+5"},
    {value: "6", label: "+6"}
  ],
  listNiveau: []

  
}
